@@ -1,6 +1,12 @@
 #!/usr/bin/env python
 # A simple milter that has grown quite a bit.
 # $Log: bms.py,v $
+# Revision 1.113  2007/09/25 16:37:26  customdesigned
+# Tested on RH7
+#
+# Revision 1.112  2007/09/13 14:51:03  customdesigned
+# Report domain on reputation reject.
+#
 # Revision 1.111  2007/07/25 17:14:59  customdesigned
 # Move milter apps to /usr/lib/pymilter
 #
@@ -280,6 +286,7 @@ milter_log = logging.getLogger('milter')
 def read_config(list):
   cp = MilterConfigParser({
     'tempdir': "/var/log/milter/save",
+    'datadir': "/var/log/milter",
     'socket': "/var/run/milter/pythonsock",
     'timeout': '600',
     'scan_html': 'no',
@@ -299,6 +306,7 @@ def read_config(list):
   })
   cp.read(list)
   if cp.has_option('milter','datadir'):
+      print "chdir:",cp.get('milter','datadir')
       os.chdir(cp.get('milter','datadir'))
 
   # milter section
@@ -537,11 +545,8 @@ class SPFPolicy(object):
 from Milter.cache import AddrCache
 
 cbv_cache = AddrCache(renew=7)
-cbv_cache.load('send_dsn.log',age=30)
 auto_whitelist = AddrCache(renew=30)
-auto_whitelist.load('auto_whitelist.log',age=120)
 blacklist = AddrCache(renew=30)
-blacklist.load('blacklist.log',age=60)
 
 class bmsMilter(Milter.Milter):
   """Milter to replace attachments poisonous to Windows with a WARNING message,
@@ -849,6 +854,7 @@ class bmsMilter(Milter.Milter):
             self.reputation = int(a[-2])
             self.confidence = int(a[-1])
             self.umis = umis
+            self.from_domain = domain
             # We would like to reject on bad reputation here, but we
             # need to give special consideration to postmaster.  So
             # we have to wait until envrcpt().  Perhaps an especially
@@ -1099,9 +1105,10 @@ class bmsMilter(Milter.Milter):
             return Milter.REJECT
           self.dspam = False
         if userl != 'postmaster' and self.umis    \
-          and self.reputation < -50 and self.confidence > 1:
+          and self.reputation < -50 and self.confidence > 3:
+          domain = self.from_domain
           self.log('REJECT: REPUTATION, rcpt to',to,str)
-          self.setreply('550','5.7.1','Your domain has been sending mostly spam')
+          self.setreply('550','5.7.1','%s has been sending mostly spam'%domain)
           return Milter.REJECT
 
         if domain in hide_path:
@@ -1826,6 +1833,10 @@ def main():
 
 if __name__ == "__main__":
   read_config(["/etc/mail/pymilter.cfg","milter.cfg"])
+
+  cbv_cache.load('send_dsn.log',age=30)
+  auto_whitelist.load('auto_whitelist.log',age=120)
+  blacklist.load('blacklist.log',age=60)
       
   if dspam_dict:
     import dspam        # low level spam check
